/****************************** Module Header ******************************\
*                                                                          *
* Copyright (c) 1994 IBM Corporation                                       *
*                                                                          *
* Module Name: idmdef.h                                                    *
*                                                                          *
\***************************************************************************/

#ifndef __IDMDEF__
#define __IDMDEF__

/********************************/
/* IDM structure definitions    */
/* are in idmtypes.idl          */
/* and in passthru section      */
/********************************/

/********************************/
/* IDMCTLDATA.ulInkStyle values */
/********************************/
#define IDM_INK_SYSTEM  0x00000000      /* Use system inking       */
#define IDM_INK_WINDOW  0x00000001      /* Use Window Inking       */
#define IDM_INKTYPE_BITMASK (IDM_INK_SYSTEM+IDM_INK_WINDOW)

#define IDM_REMOVE_INK  0x00000000      /* Remove ink at end of operation */
#define IDM_LEAVE_INK   0x00000010      /* Leave ink at end of operation */
#define IDM_REMOVEINK_BITMASK (IDM_REMOVE_INK+IDM_LEAVE_INK)

#define IDM_INVALIDATE_RECT  0x00000000 /* invalidate the bounding box or the doodle */
#define IDM_ERASE_BACKCOLOR  0x00000100 /* erase doodle to a background color        */
#define IDM_ERASE_BACKBITMAP 0x00000200 /* erase doodle to a background bitmap       */
#define IDM_ERASE_OPTION_BITMASK (IDM_ERASE_BACKCOLOR+IDM_ERASE_BACKBITMAP+IDM_INVALIDATE_RECT)

/**********************************/
/* IDMCTLDATA.ulStrokeType values */
/**********************************/
#define ST_INK          0               /* Incoming strokes are ink strokes  */
#define ST_ERASER       1               /* Incoming strokes are eraser stroke*/

/**********************************/
/* IDMCTLDATA.ulIDMOp values      */
/**********************************/
#define IDM_GESTURE     0x00000001      /* Reco incoming strokes as gestures */
#define IDM_TEXT        0x00000002      /* Reco incoming strokes are text */
#define IDM_COLLECTSTROKE 0x00000004    /* Only collect incoming strokes */

/***********************************/
/* IDMCTLDATA.ulDoodlePrePr values */
/***********************************/
#define DPP_DISPLAY     0x00000001      /* Display contents of doodle in hps */
#define DPP_NOTHING     0x00000002      /* No preprocessing of doodle        */
#define DPP_RECO        0x00000004      /* Send doodle contents to recognizer*/

/***********************************/
/* IDMCTLDATA.ulRecoTrigger values */
/***********************************/
#define RTE_EXITPROX    0x00000001      /* WM_EXIT_PROXIMITY-Stop collecting */
#define RTE_LIFTOFF     0x00000002      /* WM_LIFTOFF - Stop collecting      */
#define RTE_WRTTIMEOUT  0x00000004      /* WM_WRITING_TIMEOUT-Stop collecting*/
#define RTE_FOCUSLOST   0x00000008      /* Window Focus Lost-Stop collecting */

/***********************************/
/* IDMCTLDATA.ulNotifyFlag values  */
/***********************************/
#define IDM_ALL              0x00FFFFFF /* All notification messages     */
#define IDM_WRITING_MODE     0x00000001 /* Send IDM_WRITING_MODE         */
#define IDM_STATE_CHANGE     0x00000002 /* Send IDM_STATE_CHANGE         */
#define IDM_CONTROL_POINTER  0x00000004 /* Send IDM_CONTROL_POINTER      */
#define IDM_ENTER_PROXIMITY  0x00000008 /* Send IDM_ENTER_PROXIMITY      */
#define IDM_EXIT_PROXIMITY   0x00000010 /* Send IDM_EXIT_PROXIMITY       */
#define IDM_TOUCHDOWN        0x00000020 /* Send IDM_TOUCHDOWN            */
#define IDM_LIFTOFF          0x00000040 /* Send IDM_LIFTOFF              */

/********************************/
/* IDMCTLDATA.ulTapFlags values */
/********************************/
/* These flags have no effect when ulIDMOp is set to IDM_GESTURES */
#define IDM_FIRST_TAP_MOUSE   0x00000001    /* If first stroke is a tap, process as mouse emulation     */
#define IDM_FIRST_TAP_STROKE  0x00000002    /* If first stroke is a tap, process as a stroke            */
#define IDM_CHECK_ACTIVE      0x00000003    /* If window not active, treat first tap as mouse emulation */
#define IDM_CHECK_FOCUS       0x00000004    /* If window doesn't have focus, treat first tap as mouse emulation */
#define IDM_PROCESS_FLAGS     0x0000000F    /* If window doesn't have focus, treat first tap as mouse emulation */
#define IDM_REDUCE_TAP_LENGTH 0x00008000    /* Reduce tap length on first
stroke                        */

/***************************************************************/
/* IDM States and Notification Sub-mesages of IDM_STATE_CHANGE */
/***************************************************************/
#define IDM_STOPPED          0x00000001  /* IDM stopped, no collect, no reco*/
#define IDM_STARTED          0x00000002  /* IDM started, receiving msgs     */
#define IDM_START_COLLECTING 0x00000004  /* IDM collecting strokes          */
#define IDM_COLLECTING       0x00000004  /* IDM collecting strokes          */
#define IDM_START_RECOING    0x00000008  /* IDM adding strokes to be recoed */
#define IDM_RECOING          0x00000008  /* IDM adding strokes or recoing   */
#define IDM_STOP_COLLECTING  0x00000010  /* IDM stopped collecting strokes  */
#define IDM_STOP_RECOING     0x00000020  /* IDM done recoing strokes        */

/****************************************************************/
/* MRESULTs from WM_RESULT message - choose one from next three */
/****************************************************************/
#define IDM_HANDLE_RESULT     0x00000000  /* Handle result for application   */
#define IDM_DO_NOTHING        0x00000001  /* Application handled WM_RESULT   */
#define IDM_HANDLE_ALT_RESULT 0x00000002  /* Handle alternate result for app */

/*******************************************************************/
/* More MRESULTs from WM_RESULT message - choose one from next two */
/*******************************************************************/
#define IDM_SEND_WM_RECO      0x00000000  /* Send WM_RECO to application     */
#define IDM_DONT_SEND_WM_RECO 0x00000010  /* Dont send WM_RECO to app        */

/***********************************************/
/* idmStop - ulStopIndicator flags (bit field) */
/***********************************************/
#define SI_ABORT         0x00000001  /* Stop IDM, no IDM_NOTIFY/WM_RESULT   */
#define SI_STOPNOW       0x00000002  /* Stop IDM, send IDM_NOTIFY/WM_RESULT */

#endif
